@@ -14,7 +14,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_compute_optimizer.type_defs import (
     FilterTypeDef,
@@ -36,27 +36,27 @@ __all__ = ("ComputeOptimizerClient",)
 
 
 class Exceptions:
-    AccessDeniedException: Boto3ClientError
-    ClientError: Boto3ClientError
-    InternalServerException: Boto3ClientError
-    InvalidParameterValueException: Boto3ClientError
-    MissingAuthenticationToken: Boto3ClientError
-    OptInRequiredException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ServiceUnavailableException: Boto3ClientError
-    ThrottlingException: Boto3ClientError
+    AccessDeniedException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    InternalServerException: Type[Boto3ClientError]
+    InvalidParameterValueException: Type[Boto3ClientError]
+    MissingAuthenticationToken: Type[Boto3ClientError]
+    OptInRequiredException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ServiceUnavailableException: Type[Boto3ClientError]
+    ThrottlingException: Type[Boto3ClientError]
 
 
 class ComputeOptimizerClient:
     """
-    [ComputeOptimizer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [ComputeOptimizer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -67,7 +67,7 @@ class ComputeOptimizerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
         """
 
     def get_auto_scaling_group_recommendations(
@@ -79,7 +79,7 @@ class ComputeOptimizerClient:
         filters: List[FilterTypeDef] = None,
     ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Client.get_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        [Client.get_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
         """
 
     def get_ec2_instance_recommendations(
@@ -91,7 +91,7 @@ class ComputeOptimizerClient:
         accountIds: List[str] = None,
     ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Client.get_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        [Client.get_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
         """
 
     def get_ec2_recommendation_projected_metrics(
@@ -103,19 +103,19 @@ class ComputeOptimizerClient:
         endTime: datetime,
     ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
         """
-        [Client.get_ec2_recommendation_projected_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        [Client.get_ec2_recommendation_projected_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
         """
 
     def get_enrollment_status(self) -> GetEnrollmentStatusResponseTypeDef:
         """
-        [Client.get_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        [Client.get_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
         """
 
     def get_recommendation_summaries(
         self, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
     ) -> GetRecommendationSummariesResponseTypeDef:
         """
-        [Client.get_recommendation_summaries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        [Client.get_recommendation_summaries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
         """
 
     def update_enrollment_status(
@@ -124,5 +124,5 @@ class ComputeOptimizerClient:
         includeMemberAccounts: bool = None,
     ) -> UpdateEnrollmentStatusResponseTypeDef:
         """
-        [Client.update_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.26/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        [Client.update_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
         """
